@@ -1,3 +1,3 @@
 pub(crate) mod common;
+pub mod debug;
 pub(crate) mod function;
-pub(crate) mod lsp_helpers;
